@@ -3,6 +3,7 @@
 import time
 from .log import get_logger
 from .daemon import daemon_start
+import os
 
 try:
     logger = get_logger('/tmp/bt_panel.log',3)
@@ -31,14 +32,26 @@ def func():
                         line = line.replace(old_str, new_str)
                     file_data += line
 
-        with open(file, "w", encoding="utf-8") as f:
-            f.write(file_data)
-            log("panelPlugin.py 破解成功")
+        with open(file, "r", encoding="utf-8") as f1:
+            data = f1.read()
+        if "soft['endtime'] = 0" in data:
+            pass
+        else:
+            with open(file, "w", encoding="utf-8") as f:
+                f.write(file_data)
+                log("panelPlugin.py 破解成功")
+                # 重启面板
+                print('panelPlugin.py----重启面板')
+                try:
+                    os.system("/etc/init.d/bt restart")
+                except:
+                    pass
+
     except Exception as e:
         log("安装bt软件%s"%e)
 
 
-    #  __get_mod
+     # __get_mod
     try:
         file = '/www/server/panel/plugin/total/total_main.py'
         old_str = "if 'bt_total' in session: return public.returnMsg(True,'OK!');"
@@ -52,14 +65,24 @@ def func():
                     if old_str in line:
                         line = line.replace(old_str, new_str)
                     file_data += line
+        with open(file, "r", encoding="utf-8") as f1:
+            data = f1.read()
+        if "# if 'bt_total' in session: return public.returnMsg(True,'OK!');" in data:
+            pass
+        else:
+            with open(file, "w", encoding="utf-8") as f:
+                f.write(file_data)
+                log("total_main.py 破解成功")
+                print('total_main.py----重启面板')
+                # 重启面板
+                try:
+                    os.system("/etc/init.d/bt restart")
+                except:
+                    pass
     except Exception as e :
+        print(e)
         log("需要安装付费插件如：网站监控报表")
 
-    else:
-        with open(file, "w", encoding="utf-8") as f:
-            f.write(file_data)
-            log("total_main.py 破解成功")
-
 
     # 自动跟新 文件 修改
     try:
@@ -73,38 +96,34 @@ def func():
                     line = line.replace(old_str, new_str)
                 file_data += line
 
-        with open(file, "w", encoding="utf-8") as f:
-            f.write(file_data)
+        with open(file, "r", encoding="utf-8") as f1:
+            data = f1.read()
+        if new_str in data:
+            pass
+        else:
+            with open(file, "w", encoding="utf-8") as f:
+                f.write(file_data)
+            log("config.py 破解成功")
+            print('config.py----重启面板')
+            # 重启面板
+            try:
+                os.system("/etc/init.d/bt restart")
+            except:
+                pass
     except Exception as e:
         log("安装bt软件%s" % e)
 
 
 
-    # 自动跟新 文件 修改
-    try:
-        file = '/www/server/panel/BTPanel/templates/default/index.html'
-        old_str = "javascript:index.check_update();"
-        new_str = "#"
-        file_data = ""
-        with open(file, "r", encoding="utf-8") as f:
-            for line in f:
-                if old_str in line:
-                    line = line.replace(old_str, new_str)
-                file_data += line
-        with open(file, "w", encoding="utf-8") as f:
-            f.write(file_data)
-
-    except Exception as e:
-        log("安装bt软件%s" % e)
-
 
 def  main():
     log('start success...')
     print('start success...')
     daemon_start()
     while True:
-        time.sleep(10)
         func()
+        time.sleep(15)
+
 
 
 
